@@ -1,3 +1,4 @@
+import dask_sphinx_theme
 import requests
 import yaml
 from docutils import nodes
@@ -5,7 +6,11 @@ from docutils.parsers.rst import Directive, directives
 
 
 def get_remote_yaml(url):
-    r = requests.get(url)
+    r = requests.get(
+        url,
+        headers={"User-Agent": f"Dask sphinx theme {dask_sphinx_theme.__version__}"},
+    )
+    r.raise_for_status()
     return yaml.safe_load(r.text)
 
 
@@ -83,7 +88,7 @@ def dask_config_to_html(key, value, schema, prefix=""):
                     <dd><p>{description}</p></dd>
                     </dl>
 
-                """
+                """  # noqa
         return [node]
 
 
